@@ -13,6 +13,8 @@ module Octokit
       # @return [Sawyer::Resource] if a repository exists, false otherwise
       def repository?(repo, options = {})
         !!repository(repo, options)
+      rescue Octokit::InvalidRepository
+        false
       rescue Octokit::NotFound
         false
       end
@@ -20,6 +22,7 @@ module Octokit
       # Get a single repository
       #
       # @see https://developer.github.com/v3/repos/#get
+      # @see https://developer.github.com/v3/licenses/#get-a-repositorys-license
       # @param repo [Integer, String, Hash, Repository] A GitHub repository
       # @return [Sawyer::Resource] Repository information
       def repository(repo, options = {})
@@ -155,7 +158,7 @@ module Octokit
         if organization.nil?
           post 'user/repos', options
         else
-          post "orgs/#{organization}/repos", options
+          post "#{Organization.path organization}/repos", options
         end
       end
       alias :create_repo :create_repository
@@ -197,7 +200,7 @@ module Octokit
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository
       # @return [Array<Sawyer::Resource>] Array of hashes representing deploy keys.
-      # @see https://developer.github.com/v3/repos/keys/#list
+      # @see https://developer.github.com/v3/repos/keys/#list-deploy-keys
       # @example
       #   @client.deploy_keys('octokit/octokit.rb')
       # @example
@@ -212,7 +215,7 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param id [Integer] Deploy key ID.
       # @return [Sawyer::Resource] Deploy key.
-      # @see https://developer.github.com/v3/repos/keys/#get
+      # @see https://developer.github.com/v3/repos/keys/#get-a-deploy-key
       # @example
       #   @client.deploy_key('octokit/octokit.rb', 8675309)
       def deploy_key(repo, id, options={})
@@ -227,7 +230,7 @@ module Octokit
       # @param title [String] Title reference for the deploy key.
       # @param key [String] Public key.
       # @return [Sawyer::Resource] Hash representing newly added key.
-      # @see https://developer.github.com/v3/repos/keys/#create
+      # @see https://developer.github.com/v3/repos/keys/#add-a-new-deploy-key
       # @example
       #    @client.add_deploy_key('octokit/octokit.rb', 'Staging server', 'ssh-rsa AAA...')
       def add_deploy_key(repo, title, key, options = {})
@@ -244,7 +247,7 @@ module Octokit
       # @return [Sawyer::Resource] Updated deploy key.
       # @deprecated This method is no longer supported in the API
       # @see https://developer.github.com/changes/2014-02-24-finer-grained-scopes-for-ssh-keys/
-      # @see https://developer.github.com/v3/repos/keys/#edit
+      # @see https://developer.github.com/v3/repos/keys/#edit-a-deploy-key
       # @example Update the key for a deploy key.
       #   @client.edit_deploy_key('octokit/octokit.rb', 8675309, :key => 'ssh-rsa BBB...')
       # @example
@@ -261,7 +264,7 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param id [Integer] Id of the deploy key to remove.
       # @return [Boolean] True if key removed, false otherwise.
-      # @see https://developer.github.com/v3/repos/keys/#delete
+      # @see https://developer.github.com/v3/repos/keys/#remove-a-deploy-key
       # @example
       #   @client.remove_deploy_key('octokit/octokit.rb', 100000)
       def remove_deploy_key(repo, id, options = {})
@@ -274,7 +277,7 @@ module Octokit
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @return [Array<Sawyer::Resource>] Array of hashes representing collaborating users.
-      # @see https://developer.github.com/v3/repos/collaborators/#list
+      # @see https://developer.github.com/v3/repos/collaborators/#list-collaborators
       # @example
       #   Octokit.collaborators('octokit/octokit.rb')
       # @example
@@ -293,7 +296,7 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param collaborator [String] Collaborator GitHub username to add.
       # @return [Boolean] True if collaborator added, false otherwise.
-      # @see https://developer.github.com/v3/repos/collaborators/#add-collaborator
+      # @see https://developer.github.com/v3/repos/collaborators/#add-user-as-a-collaborator
       # @example
       #   @client.add_collaborator('octokit/octokit.rb', 'holman')
       # @example
@@ -310,7 +313,7 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param collaborator [String] Collaborator GitHub username to remove.
       # @return [Boolean] True if collaborator removed, false otherwise.
-      # @see https://developer.github.com/v3/repos/collaborators/#remove-collaborator
+      # @see https://developer.github.com/v3/repos/collaborators/#remove-user-as-a-collaborator
       # @example
       #   @client.remove_collaborator('octokit/octokit.rb', 'holman')
       # @example
@@ -327,7 +330,7 @@ module Octokit
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
       # @param collaborator [String] Collaborator GitHub username to check.
       # @return [Boolean] True if user is a collaborator, false otherwise.
-      # @see https://developer.github.com/v3/repos/collaborators/#get
+      # @see https://developer.github.com/v3/repos/collaborators/#check-if-a-user-is-a-collaborator
       # @example
       #   @client.collaborator?('octokit/octokit.rb', 'holman')
       def collaborator?(repo, collaborator, options={})
@@ -481,138 +484,42 @@ module Octokit
       end
       alias :get_branch :branch
 
-      # List repo hooks
+      # Lock a single branch from a repository
       #
-      # Requires authenticated client.
+      # Requires authenticated client
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
-      # @return [Array<Sawyer::Resource>] Array of hashes representing hooks.
-      # @see https://developer.github.com/v3/repos/hooks/#list-hooks
+      # @param branch [String] Branch name
+      # @param required_status_checks [Hash]
+      # @return [Sawyer::Resource] The protected branch
+      # @see https://developer.github.com/v3/repos/#enabling-and-disabling-branch-protection
       # @example
-      #   @client.hooks('octokit/octokit.rb')
-      def hooks(repo, options = {})
-        paginate "#{Repository.path repo}/hooks", options
+      #   @client.protect_branch('octokit/octokit.rb', 'master', foo)
+      def protect_branch(repo, branch, required_status_checks = {}, options = {})
+        if !required_status_checks.empty?
+          required_status_checks = { :required_status_checks => required_status_checks }
+        end
+
+        protection = { :protection => { :enabled => true }.merge(required_status_checks) }
+        options    = ensure_api_media_type(:branch_protection, options.merge(protection))
+
+        patch "#{Repository.path repo}/branches/#{branch}", options
       end
 
-      # Get single hook
+      # Unlock a single branch from a repository
       #
-      # Requires authenticated client.
+      # Requires authenticated client
       #
       # @param repo [Integer, String, Hash, Repository] A GitHub repository.
-      # @param id [Integer] Id of the hook to get.
-      # @return [Sawyer::Resource] Hash representing hook.
-      # @see https://developer.github.com/v3/repos/hooks/#get-single-hook
+      # @param branch [String] Branch name
+      # @return [Sawyer::Resource] The unprotected branch
+      # @see https://developer.github.com/v3/repos/#enabling-and-disabling-branch-protection
       # @example
-      #   @client.hook('octokit/octokit.rb', 100000)
-      def hook(repo, id, options = {})
-        get "#{Repository.path repo}/hooks/#{id}", options
-      end
-
-      # Create a hook
-      #
-      # Requires authenticated client.
-      #
-      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
-      # @param name [String] The name of the service that is being called. See
-      #   {https://api.github.com/hooks Hooks} for the possible names.
-      # @param config [Hash] A Hash containing key/value pairs to provide
-      #   settings for this hook. These settings vary between the services and
-      #   are defined in the {https://github.com/github/github-services github-services} repo.
-      # @option options [Array<String>] :events ('["push"]') Determines what
-      #   events the hook is triggered for.
-      # @option options [Boolean] :active Determines whether the hook is
-      #   actually triggered on pushes.
-      # @return [Sawyer::Resource] Hook info for the new hook
-      # @see https://api.github.com/hooks
-      # @see https://github.com/github/github-services
-      # @see https://developer.github.com/v3/repos/hooks/#create-a-hook
-      # @example
-      #   @client.create_hook(
-      #     'octokit/octokit.rb',
-      #     'web',
-      #     {
-      #       :url => 'http://something.com/webhook',
-      #       :content_type => 'json'
-      #     },
-      #     {
-      #       :events => ['push', 'pull_request'],
-      #       :active => true
-      #     }
-      #   )
-      def create_hook(repo, name, config, options = {})
-        options = {:name => name, :config => config, :events => ["push"], :active => true}.merge(options)
-        post "#{Repository.path repo}/hooks", options
-      end
-
-      # Edit a hook
-      #
-      # Requires authenticated client.
-      #
-      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
-      # @param id [Integer] Id of the hook being updated.
-      # @param name [String] The name of the service that is being called. See
-      #   {https://api.github.com/hooks Hooks} for the possible names.
-      # @param config [Hash] A Hash containing key/value pairs to provide
-      #   settings for this hook. These settings vary between the services and
-      #   are defined in the {https://github.com/github/github-services github-services} repo.
-      # @option options [Array<String>] :events ('["push"]') Determines what
-      #   events the hook is triggered for.
-      # @option options [Array<String>] :add_events Determines a list of events
-      #   to be added to the list of events that the Hook triggers for.
-      # @option options [Array<String>] :remove_events Determines a list of events
-      #   to be removed from the list of events that the Hook triggers for.
-      # @option options [Boolean] :active Determines whether the hook is
-      #   actually triggered on pushes.
-      # @return [Sawyer::Resource] Hook info for the updated hook
-      # @see https://api.github.com/hooks
-      # @see https://github.com/github/github-services
-      # @see https://developer.github.com/v3/repos/hooks/#edit-a-hook
-      # @example
-      #   @client.edit_hook(
-      #     'octokit/octokit.rb',
-      #     100000,
-      #     'web',
-      #     {
-      #       :url => 'http://something.com/webhook',
-      #       :content_type => 'json'
-      #     },
-      #     {
-      #       :add_events => ['status'],
-      #       :remove_events => ['pull_request'],
-      #       :active => true
-      #     }
-      #   )
-      def edit_hook(repo, id, name, config, options = {})
-        options = {:name => name, :config => config, :events => ["push"], :active => true}.merge(options)
-        patch "#{Repository.path repo}/hooks/#{id}", options
-      end
-
-      # Delete hook
-      #
-      # Requires authenticated client.
-      #
-      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
-      # @param id [Integer] Id of the hook to remove.
-      # @return [Boolean] True if hook removed, false otherwise.
-      # @see https://developer.github.com/v3/repos/hooks/#delete-a-hook
-      # @example
-      #   @client.remove_hook('octokit/octokit.rb', 1000000)
-      def remove_hook(repo, id, options = {})
-        boolean_from_response :delete, "#{Repository.path repo}/hooks/#{id}", options
-      end
-
-      # Test hook
-      #
-      # Requires authenticated client.
-      #
-      # @param repo [Integer, String, Hash, Repository] A GitHub repository.
-      # @param id [Integer] Id of the hook to test.
-      # @return [Boolean] Success
-      # @see https://developer.github.com/v3/repos/hooks/#test-a-push-hook
-      # @example
-      #   @client.test_hook('octokit/octokit.rb', 1000000)
-      def test_hook(repo, id, options = {})
-        boolean_from_response :post, "#{Repository.path repo}/hooks/#{id}/tests", options
+      #   @client.unprotect_branch('octokit/octokit.rb', 'master')
+      def unprotect_branch(repo, branch, options = {})
+        protection = { :protection => { :enabled => false } }
+        options = ensure_api_media_type(:branch_protection, options.merge(protection))
+        patch "#{Repository.path repo}/branches/#{branch}", options
       end
 
       # List users available for assigning to issues.
